<?xml version="1.0" ?><!DOCTYPE TS><TS language="ar" version="2.1">
<context>
    <name>AppearanceWidget</name>
    <message>
        <location filename="../PAppearanceWidget.ui" line="14"/>
        <source>Appearance</source>
        <translation>المظهر</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="25"/>
        <source>PageEdit</source>
        <translation>محرر الصفحات</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="31"/>
        <location filename="../PAppearanceWidget.ui" line="263"/>
        <source>Fonts:</source>
        <translation>الخطوط:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="40"/>
        <source>If no font is specified in the CSS for your page, the following font will be used to display within PageEdit. These fonts will not be used in your actual ebook.</source>
        <translation>إذا لم يُحدّد خط في لوح الطُرُز CSS لصفحتك، فسيًستخدم الخط التالي للعَرض ضمن محرر الصفحات PageEdit. لن تُستخدم هذه الخطوط في كتابك الفعلي.</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="70"/>
        <source>Default font size to be used for PageEdit
if no font-size specified in your CSS</source>
        <translation>الحجم الافتراضي للخط ليُستخدم في محرر الصفحات PageEdit 
إذا لم يُحدّد حجم خط في لوح الطُرُز CSS</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="74"/>
        <location filename="../PAppearanceWidget.ui" line="323"/>
        <source>Font Size:</source>
        <translation>حجم الخط:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="81"/>
        <source>Default font family to be used for PageEdit
if no font-family specified in your CSS</source>
        <translation>عائلة الخط الافتراضية لتُستخدم في محرر الصفحات PageEdit 
إذا لم تُحدّد عائلة خط في لوح الطُرُز CSS</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="85"/>
        <source>Standard:</source>
        <translation>القياسي:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="108"/>
        <source>Default font family to be used for PageEdit
if a serif font-family specified in your CSS</source>
        <translation>عائلة الخط الافتراضية لتُستخدم في محرر الصفحات PageEdit 
إذا حُدّدت عائلة خط مذيّلة في لوح الطُرُز CSS</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="112"/>
        <source>Serif:</source>
        <translation>المذيّل:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="125"/>
        <source>Default font family to be used for PageEdit
if a sans-serif font-family specified in your CSS</source>
        <translation>عائلة الخط الافتراضية لتُستخدم في محرر الصفحات PageEdit 
إذا حُدّدت عائلة خط مذيّلة في لوح الطُرُز CSS</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="129"/>
        <source>Sans-Serif:</source>
        <translation>غير المذيّل:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="156"/>
        <source>Make PageEdit simulate a dark appearance in dark mode</source>
        <translation>اجعل محرر الصفحات يحاكي مظهراً داكناً في النمط الداكن</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="181"/>
        <source>Main UI</source>
        <translation>الواجهة الرسومية الرئيسية</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="187"/>
        <source>Main Menu Icon Size:</source>
        <translation>حجم أيقونة القائمة الرئيسية:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="193"/>
        <source>Adjust the size of the icons in the main menu.</source>
        <translation>ضبّط حجم الأيقونات في القائمة الرئيسية.</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="231"/>
        <source>High DPI Setting:</source>
        <translation>تضبيطة DPI عالية:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="240"/>
        <source>(Needs PageEdit Restart)</source>
        <translation>(يحتاج إعادة تشغيل محرر الصفحات)</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="269"/>
        <source>UI Font:</source>
        <translation>خط واجهة المستخدم:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="279"/>
        <source>Change the font used by PageEdit&apos;s menus, buttons, etc...</source>
        <translation>غيّر الخط الذي تستخدمه قوائم محرر الصفحات وأزراره وغيرها...</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="282"/>
        <source>Change Font (Needs PageEdit Restart)</source>
        <translation>تغيير الخط (يحتاج إعادة تشغيل محرر الصفحات)</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="306"/>
        <source>Insert Special Characters:</source>
        <translation>ادراج رموز خاصة:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="320"/>
        <source>Font size to be used for Insert Special Characters window</source>
        <translation>حجم الخط الذي يًستخدم لنافذة إدراج الرموز الخاصة</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="353"/>
        <source>Font family to be used for Insert Special Characters window</source>
        <translation>عائلة الخط التي ستُتخدم لنافذة إدراج الرموز الخاصة</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="356"/>
        <source>Standard Font:</source>
        <translation>الخط الاساسي:</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="423"/>
        <source>Reset all fonts and colors to the default values</source>
        <translation>تصفير كل الخطوط والألوان إلى القيم الإفتراضية</translation>
    </message>
    <message>
        <location filename="../PAppearanceWidget.ui" line="426"/>
        <source>Reset All</source>
        <translation>اعادة تعيين الكل</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="49"/>
        <location filename="../AppearanceWidget.cpp" line="50"/>
        <source>Detect</source>
        <translation>اكتشف</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="49"/>
        <location filename="../AppearanceWidget.cpp" line="52"/>
        <source>On</source>
        <translation>تشغيل</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="49"/>
        <location filename="../AppearanceWidget.cpp" line="54"/>
        <source>Off</source>
        <translation>تعطيل</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="50"/>
        <source>Detect whether any high dpi scaling should take place.</source>
        <translation>اكتشف فيما لو سيحصل قياس عالي النقاط dpi.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="51"/>
        <source>Defers to any Qt environment variables that are set to control high dpi behavior.</source>
        <translation>يختلف عن أي متغيرات بيئة Qt معدّة للتحكم في سلوك نقاط dpi العالية.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="52"/>
        <source>Turns on high dpi scaling and ignores any Qt environment variables</source>
        <translation>يشغّل قياس نقاط dpi العالية ويهمل أية متغيرات بيئة Qt</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="53"/>
        <source>that are set controlling high dpi behavior.</source>
        <translation>المعدّة للتحكم في سلوك نقاط dpi العالية.</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="54"/>
        <source>Turns off high dpi scaling regardless if any Qt environment</source>
        <translation>يعطّل قياس نقاط dpi العالية بغضّ النظر عن أية متغيرات بيئة Qt</translation>
    </message>
    <message>
        <location filename="../AppearanceWidget.cpp" line="55"/>
        <source>variables controlling high dpi behavior are set.</source>
        <translation>متغيرات تتحكم في سلوك نقاط dpi العالية قد أُعدّت.</translation>
    </message>
</context>
<context>
    <name>GeneralSettings</name>
    <message>
        <location filename="../PGeneralSettings.ui" line="14"/>
        <source>General Settings</source>
        <translation>الاعدادات العامة</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="37"/>
        <source>You must restart PageEdit after changing the User Interface language.

If a translation for specific word or phrase is not available it will be displayed in English.</source>
        <translation>يجب أن تعيد تشغيل محرر الصفحات بعد تغيير لغة واجهة المستخدم.

إذا لم تتوفر ترجمة لكلمة أو عبارة معيَّنة فستُعرَض بالانكليزية.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="42"/>
        <source>User Interface Language:</source>
        <translation>لغة واجهة المستخدم:</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="74"/>
        <source>Select from installed spellcheck dictionaries.</source>
        <translation>اختر من بين قواميس التدقيق الإملائي المثبَّتة.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="77"/>
        <source>Spellcheck Dictionary:</source>
        <translation>قاموس التدقيق الإملائي:</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="119"/>
        <source>Determine if html files are allowed to access non-multimedia remote resources.</source>
        <translation>قرّر فيما لو يُسمَح لملفات html بالدخول إلى موارد بعيدة ليست بوسائط.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="122"/>
        <source> Control access by html files to non-multimedia remote resources.</source>
        <translation> تحكّم بدخول ملفات html إلى موارد بعيدة ليست بوسائط.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="131"/>
        <source>Check to allow html files to access non-multimedia remote resources.</source>
        <translation>أشّر لتسمح بدخول ملفات html إلى موارد بعيدة ليست بوسائط.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="134"/>
        <source>Html files may access all remote resources types.</source>
        <translation>يمكن لملفات html الدخول الى كل أنواع الموارد البعيدة.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="161"/>
        <source>Determine if javascript is allowed to be used by html files</source>
        <translation>قرر فيما لو يُسمَح لملفات html باستخدام جافاسكربت</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="164"/>
        <source> Control use of javascript by html files.</source>
        <translation> تحكّم باستخدام ملفات html لجافاسكربت.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="173"/>
        <source>Check to allow html files to use javascript.</source>
        <translation>أشّر لتسمح لملفات html باستخدام جافاسكربت.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="176"/>
        <source>Html files may use javascript.</source>
        <translation>يمكن لملفات html استخدام جافاسكربت.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="204"/>
        <source>Choose how you would like PageEdit to handle the use of multiple white space characters during editing.</source>
        <translation>اختر كيف سيتولّى محرر الصفحات استخدام رموز الفراغات البيضاء المتعددة خلال التحرير.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="207"/>
        <source>Handle multiple white space layout using:</source>
        <translation>تعامل مع مخطط الفراغات البيضاء المتعددة مستخدماً:</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="213"/>
        <source>Use CSS white-space: pre-wrap</source>
        <translation>استخدم خاصية الطُرُز white-space: pre-wrap</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="216"/>
        <source>css white-space: pre-wrap</source>
        <translation>خاصية الطُرُز white-space: pre-wrap</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="226"/>
        <source>Use non-breaking spaces as needed</source>
        <translation>استخدم الفراغات غير الفاصلة بقدر ما تحتاج</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="229"/>
        <source>non-breaking spaces as needed</source>
        <translation>الفراغات غير الفاصلة بقدر ما تحتاج</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="257"/>
        <source>Determine if Prettify is used when saving</source>
        <translation>قرر إن كان Prettify سيُستخدَم عند الحفظ</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="260"/>
        <source> Use Prettify to reformat the xhtml when saving.</source>
        <translation> استخدم Prettify لإعادة صياغة xhtml عند الحفظ.</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="269"/>
        <source>Check to reformat with Prettify when saving xhtml files.</source>
        <translation>أشّر لإعادة الصياغة بـ Prettify عند حفظ ملفات xhtml .</translation>
    </message>
    <message>
        <location filename="../PGeneralSettings.ui" line="272"/>
        <source>Use Prettify to reformat xhtml when saving.</source>
        <translation>استخدم Prettify لإعادة صياغة xhtml عند الحفظ.</translation>
    </message>
</context>
<context>
    <name>Inspector</name>
    <message>
        <location filename="../Inspector.cpp" line="74"/>
        <source>Inspect Page or Element</source>
        <translation>تفحّص صفحة أو عنصراً</translation>
    </message>
    <message>
        <location filename="../Inspector.cpp" line="156"/>
        <source>The Inspector functionality is not supported before Qt 5.11</source>
        <translation>وظيفة المتفحص Inspector غير مدعومة لما قبل Qt 5.11</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../main.ui" line="15"/>
        <location filename="../MainWindow.cpp" line="1012"/>
        <location filename="../MainWindow.cpp" line="1073"/>
        <location filename="../MainWindow.cpp" line="1764"/>
        <location filename="../MainWindow.cpp" line="1777"/>
        <location filename="../MainWindow.cpp" line="1783"/>
        <location filename="../MainWindow.cpp" line="1797"/>
        <location filename="../MainWindow.cpp" line="1810"/>
        <location filename="../MainWindow.cpp" line="1818"/>
        <location filename="../MainWindow.cpp" line="1873"/>
        <location filename="../MainWindow.cpp" line="1960"/>
        <source>PageEdit</source>
        <translation>محرر الصفحات</translation>
    </message>
    <message>
        <location filename="../main.ui" line="62"/>
        <source>&amp;File</source>
        <translation>&amp;م‍لف</translation>
    </message>
    <message>
        <location filename="../main.ui" line="75"/>
        <source>&amp;Edit</source>
        <translation>&amp;ت‍حرير</translation>
    </message>
    <message>
        <location filename="../main.ui" line="88"/>
        <source>&amp;Find</source>
        <translation>إي‍&amp;ج‍اد</translation>
    </message>
    <message>
        <location filename="../main.ui" line="95"/>
        <source>&amp;Insert</source>
        <translation>إد&amp;‍راج</translation>
    </message>
    <message>
        <location filename="../main.ui" line="110"/>
        <source>For&amp;mat</source>
        <translation>تنسي‍&amp;‍‍ق</translation>
    </message>
    <message>
        <location filename="../main.ui" line="115"/>
        <source>&amp;Heading</source>
        <translation>ت‍&amp;‍رويس</translation>
    </message>
    <message>
        <location filename="../main.ui" line="130"/>
        <source>C&amp;hange Case</source>
        <translation>تغيير &amp;حالة الحروف</translation>
    </message>
    <message>
        <location filename="../main.ui" line="160"/>
        <source>&amp;View</source>
        <translation>&amp;ع‍رض</translation>
    </message>
    <message>
        <location filename="../main.ui" line="169"/>
        <source>Inspector</source>
        <translation>المتفحّص</translation>
    </message>
    <message>
        <location filename="../main.ui" line="185"/>
        <source>File</source>
        <translation>ملف</translation>
    </message>
    <message>
        <location filename="../main.ui" line="199"/>
        <source>Edit</source>
        <translation>تحرير</translation>
    </message>
    <message>
        <location filename="../main.ui" line="217"/>
        <location filename="../main.ui" line="1157"/>
        <source>Mode</source>
        <translation>النمط</translation>
    </message>
    <message>
        <location filename="../main.ui" line="230"/>
        <source>Insert</source>
        <translation>إدراج</translation>
    </message>
    <message>
        <location filename="../main.ui" line="249"/>
        <source>Inspect</source>
        <translation>تفحّص</translation>
    </message>
    <message>
        <location filename="../main.ui" line="262"/>
        <location filename="../main.ui" line="1106"/>
        <source>Find</source>
        <translation>إيجاد</translation>
    </message>
    <message>
        <location filename="../main.ui" line="275"/>
        <source>Heading</source>
        <translation>الترويس</translation>
    </message>
    <message>
        <location filename="../main.ui" line="289"/>
        <source>set Heading Level of Selected Text</source>
        <translation>عيّن مستوى الترويس للنصّ المحدد</translation>
    </message>
    <message>
        <location filename="../main.ui" line="303"/>
        <source>Change Case</source>
        <translation>تغيير حالة الحروف</translation>
    </message>
    <message>
        <location filename="../main.ui" line="319"/>
        <source>Format</source>
        <translation>تنسيق</translation>
    </message>
    <message>
        <location filename="../main.ui" line="337"/>
        <source>Align</source>
        <translation>محاذاة</translation>
    </message>
    <message>
        <location filename="../main.ui" line="353"/>
        <source>Indent</source>
        <translation>البادئة</translation>
    </message>
    <message>
        <location filename="../main.ui" line="367"/>
        <source>Navigate</source>
        <translation>تنقّل</translation>
    </message>
    <message>
        <location filename="../main.ui" line="377"/>
        <source>Navigation List</source>
        <translation>لائحة التنقّل</translation>
    </message>
    <message>
        <location filename="../main.ui" line="393"/>
        <source>&amp;Save</source>
        <translation>&amp;ح‍فظ</translation>
    </message>
    <message>
        <location filename="../main.ui" line="396"/>
        <source>Save the current file.</source>
        <translation>احفظ الملف الحالي.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="399"/>
        <source>Ctrl+S</source>
        <translation>تحكم+ح</translation>
    </message>
    <message>
        <location filename="../main.ui" line="409"/>
        <source>&amp;Print</source>
        <translation>ا&amp;طبع</translation>
    </message>
    <message>
        <location filename="../main.ui" line="412"/>
        <source>Print the current Page.</source>
        <translation>اطبع الصفحة الحالية.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="415"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+ط</translation>
    </message>
    <message>
        <location filename="../main.ui" line="421"/>
        <source>Save &amp;As...</source>
        <translation>حفظ &amp;ب‍إسم...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="424"/>
        <source>Save the current file with a different filename.</source>
        <translation>احفظ الملف الحالي بإسم ملف مختلف.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="427"/>
        <source>Ctrl+Shift+S</source>
        <translation>تحكم+تبديل+ح</translation>
    </message>
    <message>
        <location filename="../main.ui" line="437"/>
        <source>Cu&amp;t</source>
        <translation>ق‍&amp;‍ص</translation>
    </message>
    <message>
        <location filename="../main.ui" line="440"/>
        <source>Cuts the selected text from the document and puts it on the clipboard.</source>
        <translation>يقصّ النص المحدد من المستند ويضعه في الحافظة.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="450"/>
        <source>&amp;Paste</source>
        <translation>&amp;ل‍صق</translation>
    </message>
    <message>
        <location filename="../main.ui" line="453"/>
        <source>Pastes the content from the clipboard into the file.</source>
        <translation>ألصق المحتوى من الحافظة إلى الملف.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="463"/>
        <source>&amp;Undo</source>
        <translation>&amp;اعادة</translation>
    </message>
    <message>
        <location filename="../main.ui" line="466"/>
        <source>Reverts the changes of the previous operation.</source>
        <translation>اعكس تغييرات العملية الأخيرة.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="469"/>
        <source>Ctrl+Z</source>
        <translation>تحكم+ت</translation>
    </message>
    <message>
        <location filename="../main.ui" line="479"/>
        <source>&amp;Redo</source>
        <translation>&amp;ت‍كرار</translation>
    </message>
    <message>
        <location filename="../main.ui" line="482"/>
        <source>Restores the changes reverted by the previous Undo action.</source>
        <translation>استعد التغييرات المعكوسة بعملية التراجع السابقة.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="485"/>
        <source>Ctrl+Y</source>
        <translation>تحكم+ك</translation>
    </message>
    <message>
        <location filename="../main.ui" line="495"/>
        <source>&amp;Copy</source>
        <translation>&amp;ن‍سخ</translation>
    </message>
    <message>
        <location filename="../main.ui" line="498"/>
        <source>Copies the selected text and puts it on the clipboard.</source>
        <translation>انسخ النص المحدد وضعه في الحافظة.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="511"/>
        <source>Align &amp;Left</source>
        <translation>محاذاة يسا&amp;را</translation>
    </message>
    <message>
        <location filename="../main.ui" line="514"/>
        <source>Align the paragraph to the left.</source>
        <translation>محاذاة المقطع إلى اليسار.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="528"/>
        <source>Align &amp;Right</source>
        <translation>محاذاة &amp;ي‍مينا</translation>
    </message>
    <message>
        <location filename="../main.ui" line="531"/>
        <source>Align the paragraph to the right.</source>
        <translation>محاذاة المقطع إلى اليمين.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="544"/>
        <source>&amp;Center</source>
        <translation>&amp;توسيط</translation>
    </message>
    <message>
        <location filename="../main.ui" line="547"/>
        <source>Center the paragraph.</source>
        <translation>توسيط المقطع.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="550"/>
        <source>Ctrl+E</source>
        <translation>تحكم+و</translation>
    </message>
    <message>
        <location filename="../main.ui" line="563"/>
        <source>&amp;Justify</source>
        <translation>&amp;ضبط المحاذاة</translation>
    </message>
    <message>
        <location filename="../main.ui" line="566"/>
        <source>Align the paragraph to both the left and right margins.</source>
        <translation>محاذاة المقطع إلى كل من الحواشي اليسرى واليمنى.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="569"/>
        <source>Ctrl+J</source>
        <translation>تحكم+ض</translation>
    </message>
    <message>
        <location filename="../main.ui" line="582"/>
        <source>&amp;Bold</source>
        <translation>&amp;ث‍خين</translation>
    </message>
    <message>
        <location filename="../main.ui" line="585"/>
        <source>Make the selected text bold.</source>
        <translation>اجعل النص المحدد غامقاً..</translation>
    </message>
    <message>
        <location filename="../main.ui" line="588"/>
        <source>Ctrl+B</source>
        <translation>تحكم+ث</translation>
    </message>
    <message>
        <location filename="../main.ui" line="601"/>
        <source>&amp;Italic</source>
        <translation>&amp;م‍ائل</translation>
    </message>
    <message>
        <location filename="../main.ui" line="604"/>
        <source>Make the selected text italic.</source>
        <translation>اجعل النص المحدد مائلاً.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="607"/>
        <source>Ctrl+I</source>
        <translation>تحكم+م</translation>
    </message>
    <message>
        <location filename="../main.ui" line="617"/>
        <source>&amp;Open...</source>
        <translation>&amp;ف‍تح...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="620"/>
        <source>Open a file from disk.</source>
        <translation>افتح ملفا من القرص.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="623"/>
        <source>Ctrl+O</source>
        <translation>تحكم+ف</translation>
    </message>
    <message>
        <location filename="../main.ui" line="636"/>
        <source>&amp;Underline</source>
        <translation>&amp;تحته خط</translation>
    </message>
    <message>
        <location filename="../main.ui" line="639"/>
        <source>Underline the selected text.</source>
        <translation>ضع خطا تحت النص المحدد.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="642"/>
        <source>Ctrl+U</source>
        <translation>تحكم+خ</translation>
    </message>
    <message>
        <location filename="../main.ui" line="652"/>
        <source>&amp;Lowercase</source>
        <translation>حروف &amp;صغيرة</translation>
    </message>
    <message>
        <location filename="../main.ui" line="655"/>
        <source>Set selected text to lowercase.</source>
        <translation>اجعل النص المحدد بحروف صغيرة.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="658"/>
        <source>Alt+L</source>
        <translation>Alt+L</translation>
    </message>
    <message>
        <location filename="../main.ui" line="668"/>
        <source>&amp;Uppercase</source>
        <translation>حروف &amp;كبيرة</translation>
    </message>
    <message>
        <location filename="../main.ui" line="671"/>
        <source>Set selected text to uppercase.</source>
        <translation>اجعل النص المحدد بحروف كبيرة.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="674"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../main.ui" line="684"/>
        <source>&amp;Titlecase</source>
        <translation>حالة &amp;عنوان</translation>
    </message>
    <message>
        <location filename="../main.ui" line="687"/>
        <source>Capitalize the first letter of each word selected.</source>
        <translation>اجعل الحرف الأول من كلمة محددة كبيرا.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="697"/>
        <source>&amp;Capitalize</source>
        <translation>ال‍&amp;بدأ كبيرا</translation>
    </message>
    <message>
        <location filename="../main.ui" line="700"/>
        <source>Capitalize only the first word of the selected text.</source>
        <translation>اجعل الحرف الأول فقط من النص المحدد كبيرا.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="710"/>
        <source>&amp;Quit</source>
        <translation>&amp;اغلاق</translation>
    </message>
    <message>
        <location filename="../main.ui" line="713"/>
        <source>Quit</source>
        <translation>إنهاء</translation>
    </message>
    <message>
        <location filename="../main.ui" line="716"/>
        <source>Ctrl+Q</source>
        <translation>تحكم+غ</translation>
    </message>
    <message>
        <location filename="../main.ui" line="726"/>
        <source>&amp;Special Character...</source>
        <translation>&amp;م‍حارف خاصة...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="729"/>
        <source>Select a character to insert into your text.</source>
        <translation>حدد رمزا لإدراجه في النص.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="742"/>
        <source>&amp;Numbered List</source>
        <translation>لائحة مر&amp;‌قمة</translation>
    </message>
    <message>
        <location filename="../main.ui" line="745"/>
        <source>Create a numbered list from selection.</source>
        <translation>أنشيء قائمة مرقمة من التحديد.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="758"/>
        <source>Bulle&amp;ted List</source>
        <translation>لائحة برمو&amp;ز</translation>
    </message>
    <message>
        <location filename="../main.ui" line="761"/>
        <source>Create a bulleted list from selection.</source>
        <translation>أنشيء قائمة برموز من التحديد.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="764"/>
        <source>Ctrl+Shift+L</source>
        <translation>تحكم+تحويل+ق</translation>
    </message>
    <message>
        <location filename="../main.ui" line="777"/>
        <source>Stri&amp;kethrough</source>
        <translation>يتوس‍&amp;‍ط‍ه خط</translation>
    </message>
    <message>
        <location filename="../main.ui" line="780"/>
        <source>Draw a line through the selected text.</source>
        <translation>ارسم خطاً عبر النص المحدد.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="793"/>
        <source>&amp;Subscript</source>
        <translation>نص &amp;سفلي</translation>
    </message>
    <message>
        <location filename="../main.ui" line="796"/>
        <source>Set the selected text slightly smaller and below the normal line.</source>
        <translation>اجعل النص المحدد أصغر بقليل وأسفل من السطر الاعتيادي.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="809"/>
        <source>Su&amp;perscript</source>
        <translation>نص &amp;علوي</translation>
    </message>
    <message>
        <location filename="../main.ui" line="812"/>
        <source>Set the selected text slightly smaller and above the normal line.</source>
        <translation>اجعل النص المحدد أصغر بقليل وأعلى من السطر الاعتيادي.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="823"/>
        <source>Zoom &amp;In</source>
        <translation>&amp;ت‍كبير</translation>
    </message>
    <message>
        <location filename="../main.ui" line="826"/>
        <source>Zoom In</source>
        <translation>تكبير</translation>
    </message>
    <message>
        <location filename="../main.ui" line="829"/>
        <source>Ctrl+=</source>
        <translation>تحكم+=</translation>
    </message>
    <message>
        <location filename="../main.ui" line="840"/>
        <source>Zoom &amp;Out</source>
        <translation>ت‍&amp;ص‍غير</translation>
    </message>
    <message>
        <location filename="../main.ui" line="843"/>
        <source>Zoom Out</source>
        <translation>تصغير</translation>
    </message>
    <message>
        <location filename="../main.ui" line="846"/>
        <source>Ctrl+-</source>
        <translation>تحكم+-</translation>
    </message>
    <message>
        <location filename="../main.ui" line="857"/>
        <source>Incre&amp;ase Indent</source>
        <translation>&amp;زيادة البادئة</translation>
    </message>
    <message>
        <location filename="../main.ui" line="860"/>
        <source>Increase the indent level of the paragraph.</source>
        <translation>زيادة مستوى البادئة للمقطع.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="863"/>
        <source>Ctrl+Alt+M</source>
        <translation>تحكم+تبديل+ص</translation>
    </message>
    <message>
        <location filename="../main.ui" line="873"/>
        <source>&amp;Decrease Indent</source>
        <translation>إ&amp;ن‍قاص البادئة</translation>
    </message>
    <message>
        <location filename="../main.ui" line="876"/>
        <source>Decrease the indent level of the paragraph.</source>
        <translation>إنقاص مستوى البادئة للمقطع.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="879"/>
        <source>Ctrl+Shift+M</source>
        <translation>تحكم+تحويل+ص</translation>
    </message>
    <message>
        <location filename="../main.ui" line="889"/>
        <source>Split &amp;Marker</source>
        <translation>إ&amp;ش‍ارة تقسيم</translation>
    </message>
    <message>
        <location filename="../main.ui" line="892"/>
        <source>Insert Sigil split file marker</source>
        <translation>إدراج علامة سيغل لتقسيم الملف</translation>
    </message>
    <message>
        <location filename="../main.ui" line="895"/>
        <source>Ctrl+Shift+Return</source>
        <translation>تحكم+تحويل+رجوع</translation>
    </message>
    <message>
        <location filename="../main.ui" line="901"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;التفضيلات…</translation>
    </message>
    <message>
        <location filename="../main.ui" line="904"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="910"/>
        <source>&amp;Zoom Reset</source>
        <translation>تص‍‌&amp;‍فير التكبير</translation>
    </message>
    <message>
        <location filename="../main.ui" line="913"/>
        <source>Zoom Reset</source>
        <translation>تصفير التكبير</translation>
    </message>
    <message>
        <location filename="../main.ui" line="916"/>
        <source>Ctrl+0</source>
        <translation>تجكم+0</translation>
    </message>
    <message>
        <location filename="../main.ui" line="929"/>
        <source>Heading &amp;1</source>
        <translation>ترويس &amp;1</translation>
    </message>
    <message>
        <location filename="../main.ui" line="932"/>
        <source>Format paragraph as a level 1 heading.</source>
        <translation>صِغ المقطع بشكل ترويس مستوى 1.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="935"/>
        <source>Ctrl+1</source>
        <translation>تجكم+1</translation>
    </message>
    <message>
        <location filename="../main.ui" line="948"/>
        <source>Heading &amp;2</source>
        <translation>ترويس &amp;2</translation>
    </message>
    <message>
        <location filename="../main.ui" line="951"/>
        <source>Format paragraph as a level 2 heading.</source>
        <translation>صِغ المقطع بشكل ترويس مستوى 2.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="954"/>
        <source>Ctrl+2</source>
        <translation>تجكم+2</translation>
    </message>
    <message>
        <location filename="../main.ui" line="967"/>
        <source>Heading &amp;3</source>
        <translation>ترويس &amp;3</translation>
    </message>
    <message>
        <location filename="../main.ui" line="970"/>
        <source>Format paragraph as a level 3 heading.</source>
        <translation>صِغ المقطع بشكل ترويس مستوى 3.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="973"/>
        <source>Ctrl+3</source>
        <translation>تجكم+3</translation>
    </message>
    <message>
        <location filename="../main.ui" line="987"/>
        <source>Heading &amp;4</source>
        <translation>ترويس &amp;4</translation>
    </message>
    <message>
        <location filename="../main.ui" line="990"/>
        <source>Format paragraph as a level 4 heading.</source>
        <translation>صِغ المقطع بشكل ترويس مستوى 4.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="993"/>
        <source>Ctrl+4</source>
        <translation>تجكم+4</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1006"/>
        <source>Heading &amp;5</source>
        <translation>ترويس &amp;5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1009"/>
        <source>Format paragraph as a level 5 heading.</source>
        <translation>صِغ المقطع بشكل ترويس مستوى 5.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1012"/>
        <source>Ctrl+5</source>
        <translation>تجكم+5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1025"/>
        <source>Heading &amp;6</source>
        <translation>ترويس &amp;6</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1028"/>
        <source>Format paragraph as a level 6 heading.</source>
        <translation>صِغ المقطع بشكل ترويس مستوى 6.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1031"/>
        <source>Ctrl+6</source>
        <translation>تجكم+6</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1045"/>
        <source>&amp;Normal</source>
        <translation>&amp;ع‍ادي</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1048"/>
        <source>ormat paragraph as a normal paragraph.</source>
        <translation>صِغ المقطع بشكل مقطع اعتيادي.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1051"/>
        <source>Ctrl+7</source>
        <translation>تجكم+7</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1061"/>
        <source>&amp;Preserve Existing Attributes</source>
        <translation>الاحتفا&amp;ظ بالسمات الحالية</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1064"/>
        <source>When applying this style, preserve any existing attributes on the tag</source>
        <translation>عند تطبيق هذا الطراز، حافظ على أية سِمات موجودة في الوسم</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1074"/>
        <source>&amp;Select All</source>
        <translation>تح‍&amp;ديد الكل</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1077"/>
        <source>Select all text in the document.</source>
        <translation>حدد كل النص في المستند.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1080"/>
        <source>Ctrl+A</source>
        <translation>تحكم+ل</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1090"/>
        <source>&amp;Inspector</source>
        <translation>المت‍&amp;‍ف‍حص</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1093"/>
        <source>Inspect the page.</source>
        <translation>تفحّص الصفحة.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1096"/>
        <source>Ctrl+F5</source>
        <translation>تحكم+F5</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1109"/>
        <source>Find text in the page</source>
        <translation>جد النص في الصفحة</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1112"/>
        <source>Ctrl+F</source>
        <translation>تحكم+ب</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1125"/>
        <source>Next XHtml File</source>
        <translation>ملف XHtml التالي</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1128"/>
        <source>Next file in navigation list</source>
        <translation>الملف التالي في لائحة التنقل</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1141"/>
        <source>Previous XHtml File</source>
        <translation>ملف XHtml السابق</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1144"/>
        <source>Previous file in navigation list</source>
        <translation>الملف السابق في لائحة التنقل</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1160"/>
        <source>Toggle between Edit and Preview Modes.</source>
        <translation>بدّل بين نمطي التحرير والمعاينة.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1170"/>
        <source>About...</source>
        <translation>عن البرنامج...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1173"/>
        <source>Show information about PageEdit.</source>
        <translation>أظهر معلومات عن محرر الصفحات.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1183"/>
        <source>Back to Last Link</source>
        <translation>العودة إلى الرابط الأخير</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1186"/>
        <source>Return from the last link taken</source>
        <translation>الرجوع من آخر رابط مُعالج</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1196"/>
        <source>I&amp;D...</source>
        <translation>م‍&amp;‍عرِّف...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1199"/>
        <source>Insert or edit an anchor with an ID name to use as a link target.</source>
        <translation>أدرج أو حرر مرساة ذات إسم معرِّف لاستخدامها كهدف لرابط.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1209"/>
        <source>&amp;Link...</source>
        <translation>&amp;رابط...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1212"/>
        <source>Insert or edit an anchor with a hyperlink to a target.</source>
        <translation>أدرج أو حرر مرساة ذات ارتباط تشعبي إلى هدف.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1222"/>
        <source>&amp;File...</source>
        <translation>م‍&amp;‍لف...</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1225"/>
        <source>Select existing image, video or audio files from your book to insert into the text.</source>
        <translation>حدد ملفات صور أو فيديو أو صوت موجودة من كتابك لإدراجها في النص.</translation>
    </message>
    <message>
        <location filename="../main.ui" line="1228"/>
        <source>Ctrl+Shift+I</source>
        <translation>تحكم+تحويل+ر</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="750"/>
        <source>File load failed</source>
        <translation>فشل تحميل الملف</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="751"/>
        <source>File Load Failed</source>
        <translation>فشل تحميل الملف</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="846"/>
        <source>mode: Preview</source>
        <translation>النمط: معاينة</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="848"/>
        <source>mode: Edit</source>
        <translation>النمط: تحرير</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1012"/>
        <source>Are you sure you want to open this link in your browser?

%1</source>
        <translation>أأنت متأكد أنك تريد فتح هذا الرابط في متصفحك؟

%1</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1074"/>
        <source>Do you want to save your changes before leaving?</source>
        <translation>أتريد حفظ تغييراتك قبل المغادرة؟</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1091"/>
        <source>PageEdit is closing...</source>
        <translation>محرر الصفحات يُغلَق...</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1223"/>
        <location filename="../MainWindow.cpp" line="1224"/>
        <location filename="../MainWindow.cpp" line="1225"/>
        <location filename="../MainWindow.cpp" line="1234"/>
        <location filename="../MainWindow.cpp" line="1235"/>
        <location filename="../MainWindow.cpp" line="1236"/>
        <source>HTML files (*.htm *.html *.xhtml)</source>
        <translation>ملفات HTML انترنت (‎*.htm *.html *.xhtml‏)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1226"/>
        <source>OPF files (*.opf)</source>
        <translation>ملفات OPF (‎*.opf‏)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1227"/>
        <source>All files (*.*)</source>
        <translation>كل الملفات (*.*)</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1466"/>
        <source>Save File</source>
        <translation>حفظ ملف</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1501"/>
        <location filename="../MainWindow.cpp" line="1502"/>
        <location filename="../MainWindow.cpp" line="1514"/>
        <location filename="../MainWindow.cpp" line="1515"/>
        <source>File Save-As Failed!</source>
        <translation>فشل حفظ الملف بإسم!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1501"/>
        <source>is not writeable</source>
        <translation>غير قابل للكتابة</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1510"/>
        <location filename="../MainWindow.cpp" line="1549"/>
        <source>File Saved</source>
        <translation>حُفظ الملف</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1540"/>
        <location filename="../MainWindow.cpp" line="1542"/>
        <location filename="../MainWindow.cpp" line="1553"/>
        <location filename="../MainWindow.cpp" line="1554"/>
        <source>File Save Failed!</source>
        <translation>فشل حفظ الملف!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1541"/>
        <source>does not exist or is not writeable</source>
        <translation>غير موجود أو غير قابل للكتابة</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1570"/>
        <source>Do not show this warning again</source>
        <translation>لا تُظهر هذا التحذير مرة أخرى.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1571"/>
        <source>This file may not print the way you expect it to.</source>
        <translation>قد لا يُطبع هذا الملف بالطريقة التي تتوقعها.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1572"/>
        <source>Dark backgrounds and colored text applied with an EPUB&apos;s CSS will print.</source>
        <translation>ستُطبَع الخلفيات والنصوص الملونة المطبَّقة بألواح طُرُز كتاب الكتروني.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1573"/>
        <source>Use caution as this can result in a lot of ink being used!</source>
        <translation>توخّ الحذر حيث أنّ هذا يمكن أن ينتج عنه الكثير من استخدام الحبر!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1574"/>
        <source>Use the following Print Preview to see how this file will print.</source>
        <translation>استخدم معاينة الطباعة التالية لترى كيف سيُطبَع هذا الملف.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1575"/>
        <source>Check the box if you don&apos;t wish to see this warning in the future.</source>
        <translation>أشّر المربع إذا لم ترغب في مشاهدة هذا التحذير مستقبلا.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1598"/>
        <source>Feature not available before Qt5.12.x</source>
        <translation>الميزة غير متاحة لما قبل Qt5.12.x</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1660"/>
        <source>File Opened</source>
        <translation>فُتح الملف</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1664"/>
        <source>File Open Failed!</source>
        <translation>فشل فتح الملف!</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1687"/>
        <source>Clipboard contains HTML formatting</source>
        <translation>الحافظة تحتوي صيغ HTML</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1688"/>
        <source>Do you want to paste clipboard data as plain text?</source>
        <translation>أتريد لصق بيانات الحافظة كنص بسيط؟</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1764"/>
        <source>You must select text before inserting a new id.</source>
        <translation>يجب ان تحدد نصاً قبل إدراج معرِّف جديد.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1777"/>
        <source>ID is invalid - must start with a letter, followed by letter number _ : - or .</source>
        <translation>المعرِّف غير صحيح - يجب أن يبدأ بحرف، متبوعاً بحرف أو رقم أو _ أو : أو - أو .</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1783"/>
        <source>You cannot insert an id at this position.</source>
        <translation>لا يمكنك إدراج معرّف في هذا الموضع.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1797"/>
        <source>You must select text before inserting a new link.</source>
        <translation>يجب ان تحدد نصاً قبل إدراج رابط جديد.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1810"/>
        <source>Link is invalid - cannot contain &apos;&lt;&apos; or &apos;&gt;&apos;</source>
        <translation>الرابط غير صحيح - لا يمكن أن يحتوي &apos;&lt;&apos; أو &apos;&gt;&apos;</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1818"/>
        <source>You cannot insert a link at this position.</source>
        <translation>لا يمكنك إدراج رابط في هذا الموضع.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1829"/>
        <source>Insert File</source>
        <translation>إدراج ملف</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1873"/>
        <source>You cannot insert a media file at this position.</source>
        <translation>لا يمكنك إدراج ملف وسائط في هذا الموضع.</translation>
    </message>
    <message>
        <location filename="../MainWindow.cpp" line="1961"/>
        <source>Do you want to save any changes before overwriting this file?</source>
        <translation>أتريد حفظ أية تغييرات قبل الكتابة على هذا الملف؟</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../Preferences.ui" line="14"/>
        <source>Preferences</source>
        <translation>التفضيلات</translation>
    </message>
    <message>
        <location filename="../Preferences.cpp" line="90"/>
        <source>PageEdit</source>
        <translation>محرر الصفحات</translation>
    </message>
    <message>
        <location filename="../Preferences.cpp" line="90"/>
        <source>Changes will take effect when you restart PageEdit.</source>
        <translation>ستأخذ التغييرات حيّز التنفيذ عند إعادة تشغيل محرر الصفحات.</translation>
    </message>
    <message>
        <location filename="../Preferences.cpp" line="152"/>
        <source>Open Preferences Location</source>
        <translation>افتح موضع التفضيلات</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../OPFReader.cpp" line="59"/>
        <source>Unable to read OPF file.
Line: %1 Column %2 - %3</source>
        <translation>لا يمكن قراءة ملف OPF.
السطر: %1 العمود %2 - %3</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="379"/>
        <source>Cannot read file %1:
%2.</source>
        <translation>لا يمكن قراءة الملف %1:
%2.</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="560"/>
        <source>PageEdit has encountered a problem.</source>
        <translation>واجه محرر الصفحات مشكلة.</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="561"/>
        <source>PageEdit may need to close.</source>
        <translation>قد يحتاج محرر الصفحات إلى إغلاقه.</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="863"/>
        <source>About PageEdit</source>
        <translation>عن محرر الصفحات</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="868"/>
        <source>Version</source>
        <translation>الإصدار</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="869"/>
        <source>Build Date</source>
        <translation>تاريخ التركيبة</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="870"/>
        <source>Build Time</source>
        <translation>وقت التركيبة</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="871"/>
        <source>Qt Runtime Version</source>
        <translation>إصدار دالة الوقت الحقيقي لـ QT</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="872"/>
        <source>Qt Compiled Version</source>
        <translation>إصدار QT المركَّب</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="873"/>
        <source>System</source>
        <translation>النظام</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="874"/>
        <source>Architecture</source>
        <translation>البِنية</translation>
    </message>
</context>
<context>
    <name>SearchToolbar</name>
    <message>
        <location filename="../SearchToolbar.ui" line="36"/>
        <source>Search: </source>
        <translation>البحث: </translation>
    </message>
    <message>
        <location filename="../SearchToolbar.ui" line="55"/>
        <source>Search...</source>
        <translation>بحث...</translation>
    </message>
    <message>
        <location filename="../SearchToolbar.ui" line="88"/>
        <source>&amp;Match Case</source>
        <translation>م‍&amp;طابقة حالة الحروف</translation>
    </message>
    <message>
        <location filename="../SearchToolbar.cpp" line="137"/>
        <source>No results found.</source>
        <translation>لم يُعثر على نتائج.</translation>
    </message>
</context>
<context>
    <name>SelectCharacter</name>
    <message>
        <location filename="../SelectCharacter.ui" line="14"/>
        <source>Insert Special Character</source>
        <translation>أدرج محرفاً خاصاً</translation>
    </message>
</context>
<context>
    <name>SelectFiles</name>
    <message>
        <location filename="../SelectFiles.ui" line="14"/>
        <source>Insert File</source>
        <translation>إدراج ملف</translation>
    </message>
    <message>
        <location filename="../SelectFiles.ui" line="46"/>
        <source>List only the file names which contain the text you enter.</source>
        <translation>اسرد فقط أسماء الملفات التي تحتوي النص الذي تدخله.</translation>
    </message>
    <message>
        <location filename="../SelectFiles.ui" line="49"/>
        <source>Filter:</source>
        <translation>المرشح:</translation>
    </message>
    <message>
        <location filename="../SelectFiles.ui" line="118"/>
        <source>Thumbnail size:</source>
        <translation>حجم المصغرة:</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="113"/>
        <source>All</source>
        <translation>الكل</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="114"/>
        <source>Images</source>
        <translation>الصور</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="115"/>
        <source>Video</source>
        <translation>فيديو</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="116"/>
        <source>Audio</source>
        <translation>صوت</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="159"/>
        <source>Media Files In the Book</source>
        <translation>ملفات الوسائط في الكتاب</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="162"/>
        <source>Thumbnails</source>
        <translation>المصغرات</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="325"/>
        <source>shades</source>
        <translation>ظِلال</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="325"/>
        <source>colors</source>
        <translation>الالوان</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="326"/>
        <source>Grayscale</source>
        <translation>تدرج رمادي</translation>
    </message>
    <message>
        <location filename="../SelectFiles.cpp" line="326"/>
        <source>Color</source>
        <translation>لون</translation>
    </message>
</context>
<context>
    <name>SelectHyperlink</name>
    <message>
        <location filename="../SelectHyperlink.ui" line="14"/>
        <source>Select Target</source>
        <translation>حدد الوُجهة</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="22"/>
        <source>List only the entries that match the text you enter.</source>
        <translation>فقط عَرض المُدخَلات التي تطابق النص الذي أدخلته.</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="25"/>
        <source>Filter:</source>
        <translation>المرشح:</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="58"/>
        <source>Enter the target URL for this hyperlink.  You can select or 
double click on existing destinations in your book from the list above.</source>
        <translation>أدخل الرابط الوُجهة لهذا التشعب.  يمكنك التحديد أو 
النقر المزدوج على وجهات موجودة في كتابك من اللائحة في اعلاه.</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.ui" line="62"/>
        <source>Target:</source>
        <translation>الوُجهة:</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.cpp" line="94"/>
        <source>Targets in the Book</source>
        <translation>وُجهات في الكتاب</translation>
    </message>
    <message>
        <location filename="../SelectHyperlink.cpp" line="95"/>
        <source>Text</source>
        <translation>النص</translation>
    </message>
</context>
<context>
    <name>SelectId</name>
    <message>
        <location filename="../SelectId.ui" line="14"/>
        <source>Insert ID </source>
        <translation>أدرج معرِّفاً </translation>
    </message>
    <message>
        <location filename="../SelectId.ui" line="22"/>
        <source>Enter an ID name to use as a destination for hyperlinks, notes, and TOC entries.

The dropdown box shows existing ID names in the current file.

ID names must be unique and start with a letter.</source>
        <translation>أدخل أسماء المعرِّفات لاستخدامها كوُجهات للروابط التشعبية والملاحظات ومُدخَلات المحتويات.

مربع الإنسدال يُظهر أسماء المعرِّفات الحالية في الملف الحالي.

يجب أن تكون أسماء المعرِّفات فريدة وتبدأ بحرف.</translation>
    </message>
    <message>
        <location filename="../SelectId.ui" line="29"/>
        <source>ID:</source>
        <translation>المعرِّف:</translation>
    </message>
</context>
<context>
    <name>Utility</name>
    <message>
        <location filename="../Utility.cpp" line="656"/>
        <source>PageEdit</source>
        <translation>محرر الصفحات</translation>
    </message>
    <message>
        <location filename="../Utility.cpp" line="657"/>
        <source>The requested file name contains non-ASCII characters. You should only use ASCII characters in filenames. Using non-ASCII characters can prevent the EPUB from working with some readers.

Continue using the requested filename?</source>
        <translation>اسم الملف المطلوب يحوي محارف ليست ASCII. ينبغي أن تستخدم فقط محارف ASCII في أسماء الملفات. استخدام محارف ليست ASCII يمكن أن يمنع الكتاب من العمل في بعض القارئات.

مواصلة استخدام اسم الملف المطلوب؟</translation>
    </message>
</context>
<context>
    <name>WebViewEdit</name>
    <message>
        <location filename="../WebViewEdit.cpp" line="167"/>
        <source>No suggestions</source>
        <translation>لا اقتراحات</translation>
    </message>
    <message>
        <location filename="../WebViewEdit.cpp" line="179"/>
        <source>Check Spelling</source>
        <translation>تدقيق الإملاء</translation>
    </message>
    <message>
        <location filename="../WebViewEdit.cpp" line="188"/>
        <source>Select Language</source>
        <translation>اختيار اللغة</translation>
    </message>
</context>
</TS>